@@ -735,53 +735,72 @@ a.cross (a, mp.ptValue (x2, null));
 return mp.addXPt (a);
 }var pt2 = (x2.tok == 7 ? null : mp.ptValue (x2, null));
 var plane2 = mp.planeValue (x2);
+var f = NaN;
+try {
 if (isDist) {
 var minMax = (op == -2147483648 ? 0 : op & 480);
 var isMinMax = (minMax == 32 || minMax == 64);
 var isAll = minMax == 480;
 switch (x1.tok) {
+case 7:
 case 10:
-var bs = x1.value;
-var bs2 = null;
+var isAtomSet1 = (x1.tok == 10);
+var isAtomSet2 = (x2.tok == 10);
+var isPoint2 = (x2.tok == 8);
+var bs1 = (isAtomSet1 ? x1.value : null);
+var bs2 = (isAtomSet2 ? x2.value : null);
+var list1 = (isAtomSet1 ? null : x1.getList ());
+var list2 = (isAtomSet2 ? null : x2.getList ());
 var returnAtom = (isMinMax && x3 != null && x3.asBoolean ());
 switch (x2.tok) {
 case 10:
-bs2 = (x2.tok == 10 ? x2.value : null);
+case 7:
 case 8:
 var atoms = this.vwr.ms.at;
 if (returnAtom) {
 var dMinMax = NaN;
 var iMinMax = 2147483647;
-for (var i = bs.nextSetBit (0); i >= 0; i = bs.nextSetBit (i + 1)) {
-var d = (bs2 == null ? atoms[i].distanceSquared (pt2) : (this.e.getBitsetProperty (bs2, op, atoms[i], plane2, x1.value, null, false, x1.index, false)).floatValue ());
+if (isAtomSet1) {
+for (var i = bs1.nextSetBit (0); i >= 0; i = bs1.nextSetBit (i + 1)) {
+var d = (isPoint2 ? atoms[i].distanceSquared (pt2) : (this.e.getBitsetProperty (bs2, list2, op, atoms[i], plane2, x1.value, null, false, x1.index, false)).floatValue ());
 if (minMax == 32 ? d >= dMinMax : d <= dMinMax) continue;
 dMinMax = d;
 iMinMax = i;
 }
 return mp.addXBs (iMinMax == 2147483647 ?  new JU.BS () : JU.BSUtil.newAndSetBit (iMinMax));
+}for (var i = list1.size (); --i >= 0; ) {
+var pt = JS.SV.ptValue (list1.get (i));
+var d = (isPoint2 ? pt.distanceSquared (pt2) : (this.e.getBitsetProperty (bs2, list2, op, pt, plane2, x1.value, null, false, 2147483647, false)).floatValue ());
+if (minMax == 32 ? d >= dMinMax : d <= dMinMax) continue;
+dMinMax = d;
+iMinMax = i;
+}
+return mp.addXInt (iMinMax);
 }if (isAll) {
 if (bs2 == null) {
-var data =  Clazz.newFloatArray (bs.cardinality (), 0);
-for (var p = 0, i = bs.nextSetBit (0); i >= 0; i = bs.nextSetBit (i + 1), p++) data[p] = atoms[i].distance (pt2);
+var data =  Clazz.newFloatArray (bs1.cardinality (), 0);
+for (var p = 0, i = bs1.nextSetBit (0); i >= 0; i = bs1.nextSetBit (i + 1), p++) data[p] = atoms[i].distance (pt2);
 
 return mp.addXAF (data);
-}var data2 =  Clazz.newFloatArray (bs.cardinality (), bs2.cardinality (), 0);
-for (var p = 0, i = bs.nextSetBit (0); i >= 0; i = bs.nextSetBit (i + 1), p++) for (var q = 0, j = bs2.nextSetBit (0); j >= 0; j = bs2.nextSetBit (j + 1), q++) data2[p][q] = atoms[i].distance (atoms[j]);
+}var data2 =  Clazz.newFloatArray (bs1.cardinality (), bs2.cardinality (), 0);
+for (var p = 0, i = bs1.nextSetBit (0); i >= 0; i = bs1.nextSetBit (i + 1), p++) for (var q = 0, j = bs2.nextSetBit (0); j >= 0; j = bs2.nextSetBit (j + 1), q++) data2[p][q] = atoms[i].distance (atoms[j]);
 
 
 return mp.addXAFF (data2);
 }if (isMinMax) {
-var data =  Clazz.newFloatArray (bs.cardinality (), 0);
-for (var i = bs.nextSetBit (0), p = 0; i >= 0; i = bs.nextSetBit (i + 1)) data[p++] = (this.e.getBitsetProperty (bs2, op, atoms[i], plane2, x1.value, null, false, x1.index, false)).floatValue ();
+var data =  Clazz.newFloatArray (isAtomSet1 ? bs1.cardinality () : list1.size (), 0);
+if (isAtomSet1) {
+for (var i = bs1.nextSetBit (0), p = 0; i >= 0; i = bs1.nextSetBit (i + 1)) data[p++] = (this.e.getBitsetProperty (bs2, list2, op, atoms[i], plane2, x1.value, null, false, x1.index, false)).floatValue ();
 
 return mp.addXAF (data);
-}return mp.addXObj (this.e.getBitsetProperty (bs, op, pt2, plane2, x1.value, null, false, x1.index, false));
+}for (var i = data.length; --i >= 0; ) data[i] = (this.e.getBitsetProperty (bs2, list2, op, JS.SV.ptValue (list1.get (i)), plane2, null, null, false, 2147483647, false)).floatValue ();
+
+return mp.addXAF (data);
+}return mp.addXObj (this.e.getBitsetProperty (bs1, list1, op, pt2, plane2, x1.value, null, false, x1.index, false));
 }
 }
 }var pt1 = mp.ptValue (x1, null);
 var plane1 = mp.planeValue (x1);
-var f = NaN;
-try {
 if (isDist) {
 if (plane2 != null && x3 != null) f = JU.Measure.directedDistanceToPlane (pt1, plane2, JS.SV.ptValue (x3));
  else f = (plane1 == null ? (plane2 == null ? pt2.distance (pt1) : JU.Measure.distanceToPlane (plane2, pt1)) : JU.Measure.distanceToPlane (plane1, pt2));
@@ -931,8 +950,18 @@ ret = map;
 ret = this.vwr.ms.generateCrystalClass (bs.nextSetBit (0), (args.length != 2 ? null : argLast.tok == 10 ? this.vwr.ms.getAtomSetCenter (argLast.value) : JS.SV.ptValue (argLast)));
 } else {
 var smilesFlags = (isSmiles ? (flags.indexOf ("OPEN") >= 0 ? 5 : 1) : 2) | (isON && sFind.length == 0 ? 22020096 : 0);
+if (flags.indexOf ("/MOLECULE/") >= 0) {
+var mols = this.vwr.ms.getMolecules ();
+var molList =  new JU.Lst ();
+for (var i = 0; i < mols.length; i++) {
+if (mols[i].atomList.intersects (bs)) {
+var bsRet = this.e.getSmilesExt ().getSmilesMatches (sFind, null, mols[i].atomList, bsMatch3D, smilesFlags, !isON, false);
+if (!bsRet.isEmpty ()) molList.addLast (bsRet);
+}}
+ret = molList;
+} else {
 ret = this.e.getSmilesExt ().getSmilesMatches (sFind, null, bs, bsMatch3D, smilesFlags, !isON, false);
-}break;
+}}break;
 }
 if (ret == null) this.e.invArg ();
 return mp.addXObj (ret);
@@ -2104,7 +2133,7 @@ for (var i = 0; i < args.length; i++) {
 params.addLast (args[i]);
 }
 if (isSelector) {
-return mp.addXObj (this.e.getBitsetProperty (x1.value, tok, null, null, x1.value,  Clazz.newArray (-1, [name, params]), false, x1.index, false));
+return mp.addXObj (this.e.getBitsetProperty (x1.value, null, tok, null, null, x1.value,  Clazz.newArray (-1, [name, params]), false, x1.index, false));
 }var $var = this.e.getUserFunctionResult (name, params, null);
 return ($var == null ? false : mp.addX ($var));
 }, "JS.ScriptMathProcessor,~S,~A,~N,~B");
