@@ -599,6 +599,8 @@ case '@':
 order = 2;
 index++;
 break;
+case '+':
+case '-':
 case 'H':
 break;
 case 'P':
