@@ -169,7 +169,7 @@ c;)a?null!=c.vars&&(b.append(this.getScriptID(c)),b.append(JV.StateManager.getVa
 "init",Integer.$valueOf(d));this.setShapeProperty(c,"moData",f);return this.e.sm.getShapePropertyIndex(c,"showMO",a)},"~N,~B");k(c$,"getScriptID",function(a){return"\n# "+(null==a?this.e.functionName:"function "+a.functionName)+" (file "+(null==a?this.e.scriptFileName:a.scriptFileName)+(null==a?"":" context "+a.id)+")\n"},"JS.ScriptContext");k(c$,"tokenAt",function(a,b){return a<b.length?b[a]:null},"~N,~A");c$.tokAtArray=k(c$,"tokAtArray",function(a,b){return a<b.length&&null!=b[a]?b[a].tok:0},"~N,~A");
 k(c$,"getPlotMinMax",function(a,b,c){if(null==a)return 0;switch(c){case 1111490568:case 1111490569:case 1111490570:return b?180:-180;case 1111490565:case 1111490576:return b?360:0;case 1111490574:return b?1:-1}c=b?-1E10:1E10;for(var d=a.length;0<=--d;){var f=a[d];Float.isNaN(f)||b==f>c&&(c=f)}return c},"~A,~B,~N");k(c$,"parseDataArray",function(a,b){a=JU.Parser.fixDataString(a);var c=JU.Parser.markLines(a,"\n"),d=c.length;if(!b){for(var f=JU.AU.newFloat2(d),e=0,g=0;e<d;g=c[e++])g=JU.PT.getTokens(a.substring(g,
 c[e])),JU.PT.parseFloatArrayData(g,f[e]=M(g.length,0));return f}g=JU.PT.getTokens(a.substring(0,c[0]));if(3!=g.length)return M(0,0,0,0);var h=JU.PT.parseInt(g[0]),j=JU.PT.parseInt(g[1]),k=JU.PT.parseInt(g[2]);if(1>h||1>j||1>k)return M(1,1,1,0);for(var f=JU.AU.newFloat3(h,j),p=0,m=0,e=1,g=c[0];e<d&&p<h;g=c[e++])g=JU.PT.getTokens(a.substring(g,c[e])),g.length<k||(JU.PT.parseFloatArrayData(g,f[p][m]=M(g.length,0)),++m==j&&(p++,m=0));return p!=h?(System.out.println("Error reading 3D data -- nX = "+h+
-", but only "+p+" blocks read"),M(1,1,1,0)):f},"~S,~B");k(c$,"getBitsetPropertyFloat",function(a,b,c,d,f){b=null==c||1111490843==b?this.e.getBitsetProperty(a,b,null,null,c,null,!1,2147483647,!1):this.vwr.getDataObj(c,a,1);if(null==b||!JU.AU.isAF(b))return null==a?null:M(a.cardinality(),0);if(!Float.isNaN(d))for(a=0;a<b.length;a++)b[a]<d&&(b[a]=NaN);if(!Float.isNaN(f))for(a=0;a<b.length;a++)b[a]>f&&(b[a]=NaN);return b},"JU.BS,~N,~S,~N,~N");U(c$,"ERROR_invalidArgument",22)})})(Clazz,Clazz.getClassName,
+", but only "+p+" blocks read"),M(1,1,1,0)):f},"~S,~B");k(c$,"getBitsetPropertyFloat",function(a,b,c,d,f){b=null==c||1111490843==b?this.e.getBitsetProperty(a,null,b,null,null,c,null,!1,2147483647,!1):this.vwr.getDataObj(c,a,1);if(null==b||!JU.AU.isAF(b))return null==a?null:M(a.cardinality(),0);if(!Float.isNaN(d))for(a=0;a<b.length;a++)b[a]<d&&(b[a]=NaN);if(!Float.isNaN(f))for(a=0;a<b.length;a++)b[a]>f&&(b[a]=NaN);return b},"JU.BS,~N,~S,~N,~N");U(c$,"ERROR_invalidArgument",22)})})(Clazz,Clazz.getClassName,
 Clazz.newLongArray,Clazz.doubleToByte,Clazz.doubleToInt,Clazz.doubleToLong,Clazz.declarePackage,Clazz.instanceOf,Clazz.load,Clazz.instantialize,Clazz.decorateAsClass,Clazz.floatToInt,Clazz.floatToLong,Clazz.makeConstructor,Clazz.defineEnumConstant,Clazz.exceptionOf,Clazz.newIntArray,Clazz.defineStatics,Clazz.newFloatArray,Clazz.declareType,Clazz.prepareFields,Clazz.superConstructor,Clazz.newByteArray,Clazz.declareInterface,Clazz.p0p,Clazz.pu$h,Clazz.newShortArray,Clazz.innerTypeInstance,Clazz.isClassDefined,
 Clazz.prepareCallback,Clazz.newArray,Clazz.castNullAs,Clazz.floatToShort,Clazz.superCall,Clazz.decorateAsType,Clazz.newBooleanArray,Clazz.newCharArray,Clazz.implementOf,Clazz.newDoubleArray,Clazz.overrideConstructor,Clazz.clone,Clazz.doubleToShort,Clazz.getInheritedLevel,Clazz.getParamsType,Clazz.isAF,Clazz.isAB,Clazz.isAI,Clazz.isAS,Clazz.isASS,Clazz.isAP,Clazz.isAFloat,Clazz.isAII,Clazz.isAFF,Clazz.isAFFF,Clazz.tryToSearchAndExecute,Clazz.getStackTrace,Clazz.inheritArgs,Clazz.alert,Clazz.defineMethod,
 Clazz.overrideMethod,Clazz.declareAnonymous,Clazz.cloneFinals);
